@@ -14,7 +14,6 @@
 #'
 #'
 #' @examples
-#' \dontrun{
 #'
 #' crimesub <- stpm(valenciacrimes$df[101:200, ],
 #'            names = colnames(valenciacrimes$df)[-c(1:3)],
@@ -25,14 +24,11 @@
 #'                   
 #' plot(mod1)
 #'
-#' }
 plot.sepstlppm <- function(x,
                           do.points = TRUE,
                           par = TRUE,
                           ...){
 
-  if (!inherits(x, "sepstlppm")) stop("x should an object of class sepstlppm")
-
   oldpar <- par(no.readonly = TRUE)
   on.exit(par(oldpar))
 
